Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'lib/gitlab.rb')
-rw-r--r--lib/gitlab.rb17
1 files changed, 7 insertions, 10 deletions
diff --git a/lib/gitlab.rb b/lib/gitlab.rb
index 37ce01925bb..2526a870976 100644
--- a/lib/gitlab.rb
+++ b/lib/gitlab.rb
@@ -3,21 +3,18 @@ require_dependency 'gitlab/git'
module Gitlab
COM_URL = 'https://gitlab.com'.freeze
APP_DIRS_PATTERN = %r{^/?(app|config|ee|lib|spec|\(\w*\))}
+ SUBDOMAIN_REGEX = %r{\Ahttps://[a-z0-9]+\.gitlab\.com\z}
def self.com?
- # Check `staging?` as well to keep parity with gitlab.com
- Gitlab.config.gitlab.url == COM_URL || staging?
+ # Check `gl_subdomain?` as well to keep parity with gitlab.com
+ Gitlab.config.gitlab.url == COM_URL || gl_subdomain?
end
- def self.staging?
- Gitlab.config.gitlab.url == 'https://staging.gitlab.com'
+ def self.gl_subdomain?
+ SUBDOMAIN_REGEX === Gitlab.config.gitlab.url
end
- def self.dev?
- Gitlab.config.gitlab.url == 'https://dev.gitlab.org'
- end
-
- def self.inc_controlled?
- dev? || staging? || com?
+ def self.dev_env_or_com?
+ Rails.env.test? || Rails.env.development? || com?
end
end